program PlayerAConverter_Standalone;

{$APPTYPE CONSOLE}

uses
  SysUtils,
  Classes,
  PlayerConvertUnit;

procedure ShowSyntax;
begin
  WriteLn('');
  WriteLn('Converts player_a.dat between GTA 1 Rockstar Classics/Steam Edition and GTA 1 Retail Edition (CD)');
  WriteLn('');
  WriteLn('Syntax: <TargetEdition> <FileName>');
  WriteLn('');
  WriteLn('<FileName>        Path to player_a.dat');
  WriteLn('<TargetEdition>   C for Classics, R for Retail, I for Info');
end;

var
  FileName : string;
  sourceEdition, targetEdition: TGTAEdition;

begin
  ExitCode := 30 {unknown};
  WriteLn('GTA 1 Player_a.dat converter by Daniel Marschall');

  {$REGION 'Check syntax'}
  if ParamStr(1) = '/?' then
  begin
    ShowSyntax;
    ExitCode := 0;
    Exit;
  end;

  if ParamCount <> 2 then
  begin
    ShowSyntax;
    ExitCode := 2;
    Exit;
  end;
  {$ENDREGION}

  {$REGION 'Find out target edition'}
       if ParamStr(1) = 'C' then targetEdition := geClassic
  else if ParamStr(1) = 'R' then targetEdition := geRetail
  else if ParamStr(1) = 'I' then targetEdition := geUndefined
  else
  begin
    ShowSyntax;
    WriteLn('');
    WriteLn('ERROR: Invalid target edition. Choose either C(lassic), R(etail) or I(nfo)');
    ExitCode := 2;
    Exit;
  end;
  {$ENDREGION}

  {$REGION 'Find out file name'}
  FileName := ParamStr(2);
  if not FileExists(FileName) then
  begin
    FileName := IncludeTrailingPathDelimiter(FileName) + 'player_a.dat';
  end;
  if not FileExists(FileName) then
  begin
    ShowSyntax;
    WriteLn('');
    WriteLn('ERROR: File player_a.dat not found');
    ExitCode := 2;
    Exit;
  end;
  {$ENDREGION}

  sourceEdition := GetEdition(FileName);
  
  if targetEdition = geUndefined then
  begin
    {$REGION 'Just info'}
    if sourceEdition = geClassic then
    begin
      WriteLn(Format('File %s is CLASSIC', [FileName]));
      ExitCode := 0;
      Exit;
    end
    else if sourceEdition = geRetail then
    begin
      WriteLn(Format('File %s is RETAIL', [FileName]));
      ExitCode := 0;
      Exit;
    end
    else
    begin
      WriteLn(Format('File %s is not a valid GTA 1 savestate', [FileName]));
      ExitCode := 1;
      Exit;
    end;
    {$ENDREGION}
  end
  else if targetEdition = geClassic then
  begin
    {$REGION 'Convert to CLASSIC'}
    if sourceEdition = geClassic then
    begin
      WriteLn(Format('File %s [CLASSIC] => [CLASSIC] (No change)', [FileName]));
      ExitCode := 0;
      Exit;
    end
    else if sourceEdition = geRetail then
    begin
      WriteLn(Format('File %s [RETAIL] => [CLASSIC]', [FileName]));
      ConvertTo(Filename, targetEdition);
      ExitCode := 0;
      Exit;
    end;
    {$ENDREGION}
  end
  else if targetEdition = geRetail then
  begin
    {$REGION 'Convert to RETAIL'}
    if sourceEdition = geClassic then
    begin
      WriteLn(Format('File %s [CLASSIC] => [RETAIL]', [FileName]));
      ConvertTo(Filename, targetEdition);
      ExitCode := 0;
      Exit;
    end
    else if sourceEdition = geRetail then
    begin
      WriteLn(Format('File %s [RETAIL] => [RETAIL] (No change)', [FileName]));
      ExitCode := 0;
      Exit;
    end;
    {$ENDREGION}
  end;
end.
